@@ -406,8 +406,8 @@ class Unicode:
 
 	@staticmethod
 	def parse (s):
-		s = re.sub (r"[<+>,\\uU\n	]", " ", s)
 		s = re.sub (r"0[xX]", " ", s)
+		s = re.sub (r"[<+>,;&#\\xXuU\n	]", " ", s)
 		return [int (x, 16) for x in s.split (' ') if len (x)]
 
 	@staticmethod
